Arguments
- path
The path of the new file. The path should be the absolute DBFS path (for example
/mnt/my-file.txt).- host
Databricks workspace URL, defaults to calling
db_host().- token
Databricks workspace token, defaults to calling
db_token().- perform_request
If
TRUE(default) the request is performed, ifFALSEthe httr2 request is returned without being performed.
Details
Get the file information of a file or directory.
If the file or directory does not exist, this call throws an exception with
RESOURCE_DOES_NOT_EXIST.