Repair A Job Run
db_jobs_repair_run(
run_id,
rerun_tasks = NULL,
job_parameters = list(),
latest_repair_id = NULL,
performance_target = NULL,
pipeline_full_refresh = NULL,
rerun_all_failed_tasks = NULL,
rerun_dependent_tasks = NULL,
host = db_host(),
token = db_token(),
perform_request = TRUE
)Job run ID of the run to repair. The run must not be in progress.
Character vector. Task keys of the task runs to repair.
Named list of job level parameters used in the run.
The ID of the latest repair. This parameter is not required when repairing a run for the first time, but must be provided on subsequent requests to repair the same run.
The performance mode on a serverless job (either
'PERFORMANCE_OPTIMIZED' or 'STANDARD'). The performance target determines
the level of compute performance or cost-efficiency for the run. This field
overrides the performance target defined on the job level.
Boolean. Controls whether the pipeline should perform a full refresh.
Boolean. If TRUE, repair all failed tasks.
Only one of rerun_tasks or rerun_all_failed_tasks can be used.
Boolean. If TRUE, repair all tasks that depend
on the tasks in rerun_tasks, even if they were previously successful. Can be
also used in combination with rerun_all_failed_tasks.
Databricks workspace URL, defaults to calling db_host().
Databricks workspace token, defaults to calling db_token().
If TRUE (default) the request is performed, if
FALSE the httr2 request is returned without being performed.
Parameters which are shared with db_jobs_create() are optional, only
specify those that are changing.
Other Jobs API:
db_jobs_create(),
db_jobs_delete(),
db_jobs_get(),
db_jobs_list(),
db_jobs_reset(),
db_jobs_run_now(),
db_jobs_runs_cancel(),
db_jobs_runs_delete(),
db_jobs_runs_export(),
db_jobs_runs_get(),
db_jobs_runs_get_output(),
db_jobs_runs_list(),
db_jobs_runs_submit(),
db_jobs_update()