Skip to contents

Retrieve one page of run metadata. Use next_page_token to retrieve additional array elements for large runs.

Usage

db_jobs_runs_get(
  run_id,
  page_token = NULL,
  host = db_host(),
  token = db_token(),
  perform_request = TRUE
)

Arguments

run_id

The canonical identifier of the run.

page_token

Token from a previous response, or NULL for the first page.

host

Databricks workspace URL, defaults to calling db_host().

token

Databricks workspace token, defaults to calling db_token().

perform_request

If TRUE (default) the request is performed, if FALSE the httr2 request is returned without being performed.

Value

If perform_request = TRUE, returns the full API response for one page of run details, including next_page_token when present. If FALSE, returns an httr2_request.