| db_lakebase_creds_generate | R Documentation |
Generate Database Credential
db_lakebase_creds_generate(
instance_names,
tables = NULL,
permission_set = c("READ_ONLY"),
host = db_host(),
token = db_token(),
perform_request = TRUE
)
instance_names |
Character vector of database instance names to scope the credential to. |
tables |
Optional character vector of table names to scope the credential to. |
permission_set |
Permission set for the credential request. Currently
only |
host |
Databricks workspace URL, defaults to calling |
token |
Databricks workspace token, defaults to calling |
perform_request |
If |
An idempotency token is generated automatically for each request (UUID4-like string).
List
Other Database API:
db_lakebase_get(),
db_lakebase_get_by_uid(),
db_lakebase_list()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.