Delete a Model Version Stage Transition Request
db_mlflow_model_delete_transition_req(
name,
version,
stage = c("None", "Staging", "Production", "Archived"),
creator,
comment = NULL,
host = db_host(),
token = db_token(),
perform_request = TRUE
)Name of the model.
Version of the model.
Target stage of the transition. Valid values are: None,
Staging, Production, Archived.
Username of the user who created this request. Of the transition requests matching the specified details, only the one transition created by this user will be deleted.
User-provided comment on the action.
Databricks workspace URL, defaults to calling db_host().
Databricks workspace token, defaults to calling db_token().
If TRUE (default) the request is performed, if
FALSE the httr2 request is returned without being performed.
Other Model Registry API:
db_mlflow_model_approve_transition_req(),
db_mlflow_model_open_transition_reqs(),
db_mlflow_model_reject_transition_req(),
db_mlflow_model_transition_req(),
db_mlflow_model_transition_stage(),
db_mlflow_model_version_comment(),
db_mlflow_model_version_comment_delete(),
db_mlflow_model_version_comment_edit(),
db_mlflow_registered_model_details()