List Table Summaries (Unity Catalog)
db_uc_tables_summaries(
catalog,
schema_name_pattern = NULL,
table_name_pattern = NULL,
max_results = 10000,
include_manifest_capabilities = FALSE,
page_token = NULL,
host = db_host(),
token = db_token(),
perform_request = TRUE
)List
Name of parent catalog for tables of interest.
A sql LIKE pattern (% and _) for schema
names. All schemas will be returned if not set or empty.
A sql LIKE pattern (% and _) for table names.
All tables will be returned if not set or empty.
Maximum number of summaries for tables to return (default: 10000, max: 10000). If not set, the page length is set to a server configured value.
Whether to include a manifest containing capabilities the table has.
Opaque token used to get the next page of results. Optional.
Databricks workspace URL, defaults to calling db_host().
Databricks workspace token, defaults to calling db_token().
If TRUE (default) the request is performed, if
FALSE the httr2 request is returned without being performed.
Other Unity Catalog Table Management:
db_uc_tables_delete(),
db_uc_tables_exists(),
db_uc_tables_get(),
db_uc_tables_list()