db_volume_download_dir: Download Directory from Volume in Parallel

View source: R/volume-fs.R

db_volume_download_dirR Documentation

Download Directory from Volume in Parallel

Description

Download files from a volume directory to a local directory using parallel requests.

Usage

db_volume_download_dir(
  volume_dir,
  local_dir,
  overwrite = TRUE,
  recursive = TRUE,
  host = db_host(),
  token = db_token()
)

Arguments

volume_dir

Volume directory path (must start with /Volumes/)

local_dir

Path to local directory where files will be downloaded

overwrite

Flag to overwrite existing local files (default: TRUE)

recursive

If TRUE, recursively include subdirectories (default: TRUE). If FALSE, only top-level files are transferred.

host

Databricks workspace URL, defaults to calling db_host().

token

Databricks workspace token, defaults to calling db_token().

Value

TRUE if all downloads successful

See Also

Other Volumes FileSystem API: db_volume_delete(), db_volume_dir_create(), db_volume_dir_delete(), db_volume_dir_exists(), db_volume_file_exists(), db_volume_list(), db_volume_read(), db_volume_upload_dir(), db_volume_write()


brickster documentation built on July 24, 2026, 9:08 a.m.