Upload a file to volume filesystem.
Arguments
- path
Absolute path of the file in the Files API, omitting the initial slash.
- file
Path to a file on local system, takes precedent over
path.- overwrite
Flag (Default:
FALSE) that specifies whether to overwrite existing files.- host
Databricks workspace URL, defaults to calling
db_host().- token
Databricks workspace token, defaults to calling
db_token().- perform_request
If
TRUE(default) the request is performed, ifFALSEthe httr2 request is returned without being performed.- progress
If
TRUE, show progress bar for file operations (default:TRUEfor uploads/downloads,FALSEfor other operations)
Value
If perform_request = TRUE, returns endpoint-specific API output. If FALSE, returns an httr2_request.