Gets the status of an object or a directory.
db_workspace_get_status(
path,
host = db_host(),
token = db_token(),
perform_request = TRUE
)Absolute path of the notebook or directory.
Databricks workspace URL, defaults to calling db_host().
Databricks workspace token, defaults to calling db_token().
If TRUE (default) the request is performed, if
FALSE the httr2 request is returned without being performed.
If path does not exist, this call returns an error RESOURCE_DOES_NOT_EXIST.
Other Workspace API:
db_workspace_delete(),
db_workspace_export(),
db_workspace_import(),
db_workspace_list(),
db_workspace_mkdirs()