read_databrickscfg: Reads Databricks CLI Config

View source: R/package-auth.R

read_databrickscfgR Documentation

Reads Databricks CLI Config

Description

Reads Databricks CLI Config

Usage

read_databrickscfg(
  key = c("token", "host", "wsid", "client_id", "client_secret", "azure_client_id",
    "azure_client_secret", "azure_tenant_id", "auth_type"),
  profile = NULL,
  error = TRUE
)

Arguments

key

The value to fetch from profile. One of token, host, wsid, client_id, client_secret, azure_client_id, azure_client_secret, azure_tenant_id, or auth_type

profile

Character, the name of the profile to retrieve values

Details

Reads .databrickscfg file and retrieves the values associated to a given profile. Brickster searches for the config file in the user's home directory by default. To see where this is you can run Sys.getenv("HOME") on unix-like operating systems, or, Sys.getenv("USERPROFILE") on windows. An alternate location will be used if the environment variable DATABRICKS_CONFIG_FILE is set.

Value

named list of values associated with profile


brickster documentation built on July 24, 2026, 9:08 a.m.