| dbConnect,DatabricksDriver-method | R Documentation |
Connect to Databricks SQL Warehouse
## S4 method for signature 'DatabricksDriver'
dbConnect(
drv,
warehouse_id = NULL,
http_path = NULL,
catalog = NULL,
schema = NULL,
staging_volume = NULL,
disposition = c("EXTERNAL_LINKS", "INLINE"),
max_active_connections = 30,
fetch_timeout = 300,
show_progress = TRUE,
token = db_token(),
host = db_host(),
...
)
drv |
A DatabricksDriver object |
warehouse_id |
Optional ID of the SQL warehouse to connect to |
http_path |
Optional HTTP path for the SQL warehouse; if provided, the warehouse ID is extracted from this path |
catalog |
Optional catalog name to use as default |
schema |
Optional schema name to use as default |
staging_volume |
Optional volume path for large dataset staging |
disposition |
Query disposition mode to use by default for DBI query
results. Use |
max_active_connections |
Maximum number of concurrent download connections when fetching query results (default: 30) |
fetch_timeout |
Timeout in seconds for downloading each result chunk (default: 300) |
show_progress |
If |
token |
Authentication token (defaults to db_token()) |
host |
Databricks workspace host (defaults to db_host()) |
... |
Additional arguments (ignored) |
Provide either warehouse_id or http_path. When http_path is
supplied, the warehouse ID is extracted from the /warehouses/<id> segment.
A DatabricksConnection object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.