Skip to contents

List Clusters

Usage

db_cluster_list(host = db_host(), token = db_token(), perform_request = TRUE)

Arguments

host

Databricks workspace URL, defaults to calling db_host().

token

Databricks workspace token, defaults to calling db_token().

perform_request

If TRUE (default) the request is performed, if FALSE the httr2 request is returned without being performed.

Value

If perform_request = TRUE, returns a nested list of clusters with class db_cluster_list; each element has class db_cluster. If FALSE, returns an httr2_request.

Details

Return information about all pinned clusters, active clusters, up to 150 of the most recently terminated all-purpose clusters in the past 30 days, and up to 30 of the most recently terminated job clusters in the past 30 days.

For example, if there is 1 pinned cluster, 4 active clusters, 45 terminated all-purpose clusters in the past 30 days, and 50 terminated job clusters in the past 30 days, then this API returns:

  • the 1 pinned cluster

  • 4 active clusters

  • All 45 terminated all-purpose clusters

  • The 30 most recently terminated job clusters