Permanently Delete a Cluster
Arguments
- cluster_id
Canonical identifier for the cluster.
- host
Databricks workspace URL, defaults to calling
db_host().- token
Databricks workspace token, defaults to calling
db_token().- perform_request
If
TRUE(default) the request is performed, ifFALSEthe httr2 request is returned without being performed.
Value
If perform_request = TRUE, returns endpoint-specific API output. If FALSE, returns an httr2_request.
Details
If the cluster is running, it is terminated and its resources are asynchronously removed. If the cluster is terminated, then it is immediately removed.
You cannot perform *any action, including retrieve the cluster’s permissions, on a permanently deleted cluster. A permanently deleted cluster is also no longer returned in the cluster list.
See also
Other Clusters API:
db_cluster_create(),
db_cluster_edit(),
db_cluster_events(),
db_cluster_get(),
db_cluster_list(),
db_cluster_list_node_types(),
db_cluster_list_zones(),
db_cluster_pin(),
db_cluster_resize(),
db_cluster_restart(),
db_cluster_runtime_versions(),
db_cluster_start(),
db_cluster_terminate(),
db_cluster_unpin(),
get_and_start_cluster(),
get_latest_dbr()