Arguments
- path
The path of the new file. The path should be the absolute DBFS path (for example
/mnt/my-file.txt).- host
Databricks workspace URL, defaults to calling
db_host().- token
Databricks workspace token, defaults to calling
db_token().- perform_request
If
TRUE(default) the request is performed, ifFALSEthe httr2 request is returned without being performed.
Details
Create the given directory and necessary parent directories if they do not exist.
If there exists a file (not a directory) at any prefix of the input path, this call throws an exception with
RESOURCE_ALREADY_EXISTS.If this operation fails it may have succeeded in creating some of the necessary parent directories.