List runs in descending order by end time, or start time for unfinished runs.
Arguments
- job_id
The canonical identifier of the job.
- active_only
Boolean (Default:
FALSE). IfTRUEonly active runs are included in the results; otherwise, lists both active and completed runs. An active run is a run in thePENDING,RUNNING, orTERMINATING. This field cannot be true whencompleted_onlyisTRUE.- completed_only
Boolean (Default:
FALSE). IfTRUE, only completed runs are included in the results; otherwise, lists both active and completed runs. This field cannot be true whenactive_onlyisTRUE.- offset
Number of records to skip. Defaults to
NULL.- limit
Number of runs to return, from 1 to 25 (default: 25). A value of 0 requests the service maximum.
- run_type
The type of runs to return. One of
JOB_RUN,WORKFLOW_RUN,SUBMIT_RUN.- expand_tasks
Whether to include task and cluster details in the response.
- page_token
Token from a previous response, or
NULLfor the first page.- host
Databricks workspace URL, defaults to calling
db_host().- token
Databricks workspace token, defaults to calling
db_token().- perform_request
If
TRUE(default) the request is performed, ifFALSEthe httr2 request is returned without being performed.
Value
If perform_request = TRUE, returns the full single-page API
response as a list, including runs, next_page_token, and prev_page_token
when present. The runs field may be absent when there are no runs to list.
If perform_request = FALSE, returns an httr2_request.