List runs in descending order by start time.
db_jobs_runs_list(
job_id,
active_only = FALSE,
completed_only = FALSE,
offset = 0,
limit = 25,
run_type = c("JOB_RUN", "WORKFLOW_RUN", "SUBMIT_RUN"),
expand_tasks = FALSE,
host = db_host(),
token = db_token(),
perform_request = TRUE
)The canonical identifier of the job.
Boolean (Default: FALSE). If TRUE only active runs are
included in the results; otherwise, lists both active and completed runs.
An active run is a run in the PENDING, RUNNING, or TERMINATING. This
field cannot be true when completed_only is TRUE.
Boolean (Default: FALSE). If TRUE, only completed
runs are included in the results; otherwise, lists both active and completed
runs. This field cannot be true when active_only is TRUE.
The offset of the first job to return, relative to the most recently created job.
Number of jobs to return. This value must be greater than 0 and less or equal to 25. The default value is 25. If a request specifies a limit of 0, the service instead uses the maximum limit.
The type of runs to return. One of JOB_RUN, WORKFLOW_RUN,
SUBMIT_RUN.
Whether to include task and cluster details in the response.
Databricks workspace URL, defaults to calling db_host().
Databricks workspace token, defaults to calling db_token().
If TRUE (default) the request is performed, if
FALSE the httr2 request is returned without being performed.
Other Jobs API:
db_jobs_create(),
db_jobs_delete(),
db_jobs_get(),
db_jobs_list(),
db_jobs_reset(),
db_jobs_run_now(),
db_jobs_runs_cancel(),
db_jobs_runs_delete(),
db_jobs_runs_export(),
db_jobs_runs_get(),
db_jobs_runs_get_output(),
db_jobs_runs_submit(),
db_jobs_update()