Generate Database Credential
db_lakebase_creds_generate(
instance_names,
tables = NULL,
permission_set = c("READ_ONLY"),
host = db_host(),
token = db_token(),
perform_request = TRUE
)List
Character vector of database instance names to scope the credential to.
Optional character vector of table names to scope the credential to.
Permission set for the credential request. Currently
only READ_ONLY is supported.
Databricks workspace URL, defaults to calling db_host().
Databricks workspace token, defaults to calling db_token().
If TRUE (default) the request is performed, if
FALSE the httr2 request is returned without being performed.
An idempotency token is generated automatically for each request (UUID4-like string).
Other Database API:
db_lakebase_get(),
db_lakebase_get_by_uid(),
db_lakebase_list()