Learn R Programming

brickster (version 0.2.11)

db_lakebase_creds_generate: Generate Database Credential

Description

Generate Database Credential

Usage

db_lakebase_creds_generate(
  instance_names,
  tables = NULL,
  permission_set = c("READ_ONLY"),
  host = db_host(),
  token = db_token(),
  perform_request = TRUE
)

Value

List

Arguments

instance_names

Character vector of database instance names to scope the credential to.

tables

Optional character vector of table names to scope the credential to.

permission_set

Permission set for the credential request. Currently only READ_ONLY is supported.

host

Databricks workspace URL, defaults to calling db_host().

token

Databricks workspace token, defaults to calling db_token().

perform_request

If TRUE (default) the request is performed, if FALSE the httr2 request is returned without being performed.

Details

An idempotency token is generated automatically for each request (UUID4-like string).

See Also

Other Database API: db_lakebase_get(), db_lakebase_get_by_uid(), db_lakebase_list()