Get All Repos
Arguments
- path_prefix
Filters repos that have paths starting with the given path prefix.
- next_page_token
Token used to get the next page of results. If not specified, returns the first page of results as well as a next page token if there are more results.
- host
Databricks workspace URL, defaults to calling
db_host().- token
Databricks workspace token, defaults to calling
db_token().- perform_request
If
TRUE(default) the request is performed, ifFALSEthe httr2 request is returned without being performed.
Value
If perform_request = TRUE, returns endpoint-specific API output. If FALSE, returns an httr2_request.
Details
Returns repos that the calling user has Manage permissions on. Results are paginated with each page containing twenty repos.
See also
Other Repos API:
db_repo_create(),
db_repo_delete(),
db_repo_get(),
db_repo_update()