Download files from a volume directory to a local directory using parallel requests.
Arguments
- volume_dir
Volume directory path (must start with /Volumes/)
- local_dir
Path to local directory where files will be downloaded
- overwrite
Flag to overwrite existing local files (default:
TRUE)- recursive
If
TRUE, recursively include subdirectories (default:TRUE). IfFALSE, only top-level files are transferred.- host
Databricks workspace URL, defaults to calling
db_host().- token
Databricks workspace token, defaults to calling
db_token().
See also
Other Volumes FileSystem API:
db_volume_delete(),
db_volume_dir_create(),
db_volume_dir_delete(),
db_volume_dir_exists(),
db_volume_file_exists(),
db_volume_list(),
db_volume_read(),
db_volume_upload_dir(),
db_volume_write()