| db_volume_download_dir | R Documentation |
Download files from a volume directory to a local directory using parallel requests.
db_volume_download_dir(
volume_dir,
local_dir,
overwrite = TRUE,
recursive = TRUE,
host = db_host(),
token = db_token()
)
volume_dir |
Volume directory path (must start with /Volumes/) |
local_dir |
Path to local directory where files will be downloaded |
overwrite |
Flag to overwrite existing local files (default: |
recursive |
If |
host |
Databricks workspace URL, defaults to calling |
token |
Databricks workspace token, defaults to calling |
TRUE if all downloads successful
Other Volumes FileSystem API:
db_volume_delete(),
db_volume_dir_create(),
db_volume_dir_delete(),
db_volume_dir_exists(),
db_volume_file_exists(),
db_volume_list(),
db_volume_read(),
db_volume_upload_dir(),
db_volume_write()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.