Make a Directory (Workspaces)
Arguments
- path
Absolute path of the directory.
- host
Databricks workspace URL, defaults to calling
db_host().- token
Databricks workspace token, defaults to calling
db_token().- perform_request
If
TRUE(default) the request is performed, ifFALSEthe httr2 request is returned without being performed.
Value
If perform_request = TRUE, returns endpoint-specific API output. If FALSE, returns an httr2_request.
Details
Create the given directory and necessary parent directories if they do not
exists. If there exists an object (not a directory) at any prefix of the
input path, this call returns an error RESOURCE_ALREADY_EXISTS. If this
operation fails it may have succeeded in creating some of the necessary
parent directories.
See also
Other Workspace API:
db_workspace_delete(),
db_workspace_export(),
db_workspace_get_status(),
db_workspace_import(),
db_workspace_list()